@@ -922,7 +922,7 @@ class Sequence(Generic[T], Iterable[T]):
         lst.reverse()
         return it(lst)
 
-    def flat_map(self, transform: Callable[[T], Sequence[R]]) -> Sequence[R]:
+    def flat_map(self, transform: Callable[[T], Iterable[R]]) -> Sequence[R]:
         """
          Returns a single list of all elements yielded from results of [transform]
         function being invoked on each element of original collection.
